@@ -1,5 +1,5 @@
 /* qshutdown, a program to shutdown/reboot/suspend/hibernate the system
- * Copyright (C) 2010-2011 Christian Metscher <hakaishi@web.de>
+ * Copyright (C) 2010-2013 Christian Metscher <hakaishi@web.de>
 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -61,13 +61,31 @@ Preferences::Preferences(QWidget *parent): QDialog(parent){
      userDef4S = tr("Please input an user specified command for hibernate here");
 
      msgBox = new QMessageBox(this);
-     msgBox->setWindowTitle("Error");
+     msgBox->setWindowTitle(tr("Error"));
      msgBox->setIcon(QMessageBox::Warning);
      msgBox->setWindowFlags(Qt::WindowStaysOnTopHint | Qt::Window);
      msgBox->setInformativeText(tr("The File \"%1\" is not writable!\n"
      "Maybe you just don't have the permissions to do so.").arg(file));
 
-     connect(buttonBox, SIGNAL(accepted()), this, SLOT(saveToConfFile()));
+     if(QSettings().value("first_start", true).toBool())
+     {
+       infoBox = new QMessageBox(this);
+       infoBox->setWindowTitle(tr("Please read this carefully!"));
+       infoBox->setIcon(QMessageBox::Information);
+       infoBox->setInformativeText(tr("Welcome to qshutdown!\n"
+         "If you want qshutdown e.g. to shutdown the system "
+         "and you are using the Gnome Shell, then you are likely to get a "
+         "shutdown dialog from there. If you want a direct shutdown, then "
+         "please consider going into the preferences and setting the shutdown "
+         "method to ConsoleKit or something else.\n\nPlease feel free to visit "
+         "https://launchpad.net/~hakaishi to report bugs or for anyting "
+         "concerning translations."));
+       infoBox->setStandardButtons(QMessageBox::Ok);
+       infoBox->show();
+       QSettings().setValue("first_start", false);
+     }
+
+     connect(this, SIGNAL(accepted()), this, SLOT(saveToConfFile()));
      connect(reset, SIGNAL(clicked(bool)), this, SLOT(resetSettings()));
      connect(font1Spin, SIGNAL(valueChanged(int)), this, SLOT(fontSize1Changed(int)));
      connect(font2Spin, SIGNAL(valueChanged(int)), this, SLOT(fontSize2Changed(int)));
@@ -104,7 +122,7 @@ void Preferences::showEvent(QShowEvent* show_pref){
        msgBox->show();
      }
      loadSettings();
-     QWidget::showEvent(show_pref);
+     QDialog::showEvent(show_pref);
 }
 
 void Preferences::setFocusToUserDef(){
@@ -298,7 +316,7 @@ void Preferences::closeEvent(QCloseEvent* close_pref){
      if(settings->isWritable())
        settings->setValue("PrefWindowSize/size",size());
      resetFont();
-     QWidget::closeEvent(close_pref);
+     QDialog::closeEvent(close_pref);
 }
 
 bool Preferences::getClosed(){ return isClosed; }
